/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.beans;

import shohaku.core.lang.ObjectCreationException;

/**
 * オブジェクトインスタンスを生成する機能を示すインタフェースを提供します。<br>
 * このインターフェースは松柏 JavaBean API 間で値の生成を連携させる役割を持ちます。<br>
 * このインターフェースを実装するクラスは、そのインスタンスではなく生成された値を処理の対象とします。<br>
 * 例えば <code>ArgumentInfo</code> に値として格納された場合はその生成値を値とします。
 */
public interface ObjectGenerator {

    /**
     * 生成されるオブジェクト型を可能な限り厳密な型で返却します。
     * 
     * @return 可能な限り厳密な生成するオブジェクト型
     */
    Class getInstanceType();

    /**
     * インスタンスを生成して返却します。
     * 
     * @return 生成されたインスタンス
     * @throws ObjectCreationException
     *             オブジェクトの生成に失敗した場合に発生します
     */
    Object getInstance() throws ObjectCreationException;

}
