/*
 * shohaku Copyright (C) 2005 tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package shohaku.core.collections;

import java.util.Iterator;
import java.util.List;

import shohaku.core.collections.wrapper.WrappedList;

/**
 * <code>List</code>インタフェースのユーティリティメソッドを提供します。
 */
public class ListUtils {

    /**
     * リスト型にラッピングしたリストを返却します。 実装型に固有の機能へのアクセスを制限します。
     * 
     * @param list
     *            ラップするリスト
     * @return 実装をラッピングしたリスト
     */
    public static List wrappedList(List list) {
        return new WrappedList(list);
    }

    /**
     * リストに反復子の要素を全て追加します。
     * 
     * @param l
     *            追加先のリスト
     * @param elements
     *            追加する反復子
     * @return 引数のリスト参照
     */
    public static List addAll(List l, Iterator elements) {
        while (elements.hasNext()) {
            l.add(elements.next());
        }
        return l;
    }

    /**
     * リスト内の指定された位置に、反復子の要素を全て追加します。<br>
     * 現在その位置にある要素と後続の要素は右に移動します (インデックス値が増加)。
     * 
     * @param l
     *            追加先のリスト
     * @param index
     *            指定されたコレクションから最初の要素を挿入する位置のインデックス
     * @param elements
     *            追加する反復子
     * @return 引数のリスト参照
     */
    public static List addAll(List l, int index, Iterator elements) {
        while (elements.hasNext()) {
            l.add(index++, elements.next());
        }
        return l;
    }

}
