/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.collections;

/**
 * 配列またはリストの構造をもつデータに対しアクセスするための軽量インターフェースを提供します。
 */
public interface Sequence {

    /**
     * 指定のインデックスの要素を返却します。<br>
     * インデックスが範囲外の場合は<code>IllegalArgumentException</code>が発生します。
     * 
     * @param index
     *            インデックス
     * @return インデックスの要素
     * @throws IllegalArgumentException
     *             インデックスが範囲外の場合
     */
    Object get(int index);

    /**
     * 指定のインデックスの要素を変更して既存の要素を返却します。<br>
     * インデックスが範囲外の場合は<code>IllegalArgumentException</code>が発生します。
     * 
     * @param index
     *            インデックス
     * @param e
     *            追加する要素
     * @return 既存の要素
     * @throws IllegalArgumentException
     *             インデックスが範囲外の場合
     */
    Object set(int index, Object e);

    /**
     * 要素数を返却します。<br>
     * <code>Integer.MAX_VALUE</code>より多くの要素がある場合は、<code>Integer.MAX_VALUE</code>を返します。
     * 
     * @return 要素数
     */
    int size();

}
