/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.collections;

import java.util.List;

/**
 * <code>Sequence</code>インタフェースのユーティリティメソッドを提供します。
 */
public class SequenceUtils {

    /**
     * 配列の<code>Sequence</code>ビューを返却します。
     * 
     * @param src
     *            ラップする配列
     * @return 配列の<code>Sequence</code>ビュー
     */
    public static Sequence asSequence(final Object[] src) {
        return new Sequence() {

            public Object get(int index) {
                return src[index];
            }

            public Object set(int index, Object e) {
                Object old = src[index];
                src[index] = e;
                return old;
            }

            public int size() {
                return src.length;
            }

        };
    }

    /**
     * リストの<code>Sequence</code>ビューを返却します。
     * 
     * @param src
     *            ラップするリスト
     * @return リストの<code>Sequence</code>ビュー
     */
    public static Sequence asSequence(final List src) {
        return new Sequence() {

            public Object get(int index) {
                return src.get(index);
            }

            public Object set(int index, Object e) {
                return src.set(index, e);
            }

            public int size() {
                return src.size();
            }

        };
    }

}
