/*
 * shohaku Copyright (C) 2005 tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package shohaku.core.collections.wrapper;

import java.util.Set;

/**
 * 指定されたセットをラッピングするビューを提供します。 <br>
 * <br>
 * このクラスはセットの実装を隠蔽する目的で使用されます。またセットをラッピングするクラスの基底実装の役割を持ちます。<br>
 * ラッピングされたセットが直列化可能の場合は直列化可能です。
 */
public class WrappedSet extends WrappedCollection implements Set {

    /** <code>serialVersionUID</code>。 */
    private static final long serialVersionUID = 1597202985658004285L;

    /** 基となるセット。 */
    protected final Set set;

    /**
     * ラップするセットを指定して初期化します。
     * 
     * @param s
     *            ラップするセット
     */
    public WrappedSet(Set s) {
        super(s);
        this.set = s;
    }

    /**
     * 基となるセットの同メソッドを呼び出します。
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    public boolean equals(Object o) {
        return set.equals(o);
    }

    /**
     * 基となるセットの同メソッドを呼び出します。
     * 
     * @see java.lang.Object#hashCode()
     */
    public int hashCode() {
        return set.hashCode();
    }
}