/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.helpers;

/**
 * 値を評価する式のヘルパーメソッド群の拡張機能を提供します。
 */
public class EvalX {

    /*
     * Range
     */

    /**
     * 指定された文字シーケンスが指定の文字列数と同一であると同時に文字の範囲内か評価します。
     * 
     * @param cs
     *            評価する文字シーケンス
     * @param length
     *            文字列数
     * @param from
     *            範囲の最小値
     * @param to
     *            範囲の最大値
     * @return 指定の文字列数と同一であると同時に文字の範囲内の場合のみ<code>true</code>
     */
    public static boolean isSizeAndRangeChars(CharSequence cs, int length, char from, char to) {
        return (Eval.isSize(cs, length) && Eval.isRangeChars(cs, from, to));
    }

    /**
     * 指定された文字シーケンスが指定の文字列数と指定の文字の範囲内か評価します。
     * 
     * @param cs
     *            評価する文字シーケンス
     * @param min
     *            文字数の最小値
     * @param max
     *            文字数の最大値
     * @param from
     *            範囲の最小値
     * @param to
     *            範囲の最大値
     * @return 指定の文字列数と文字の範囲内の場合のみ<code>true</code>
     */
    public static boolean isRangeSizeAndChars(CharSequence cs, int min, int max, char from, char to) {
        return (Eval.isSize(cs, min, max) && Eval.isRangeChars(cs, from, to));
    }

    /*
     * Range All
     */

    /**
     * 指定された数値が指定の範囲内か評価します。
     * 
     * @param a
     *            評価する数値
     * @param from
     *            範囲の最小値
     * @param to
     *            範囲の最大値
     * @return 指定の範囲内の場合のみ<code>true</code>
     */
    public static boolean isRangeAll(byte[] a, byte from, byte to) {
        for (int i = 0; i < a.length; i++) {
            if (!Eval.isRange(a[i], from, to)) {
                return false;
            }
        }
        return true;
    }

    /**
     * 指定された数値が指定の範囲内か評価します。
     * 
     * @param a
     *            評価する数値
     * @param from
     *            範囲の最小値
     * @param to
     *            範囲の最大値
     * @return 指定の範囲内の場合のみ<code>true</code>
     */
    public static boolean isRangeAll(short[] a, short from, short to) {
        for (int i = 0; i < a.length; i++) {
            if (!Eval.isRange(a[i], from, to)) {
                return false;
            }
        }
        return true;
    }

    /**
     * 指定された数値が指定の範囲内か評価します。
     * 
     * @param a
     *            評価する数値
     * @param from
     *            範囲の最小値
     * @param to
     *            範囲の最大値
     * @return 指定の範囲内の場合のみ<code>true</code>
     */
    public static boolean isRangeAll(int[] a, int from, int to) {
        for (int i = 0; i < a.length; i++) {
            if (!Eval.isRange(a[i], from, to)) {
                return false;
            }
        }
        return true;
    }

    /**
     * 指定された数値が指定の範囲内か評価します。
     * 
     * @param a
     *            評価する数値
     * @param from
     *            範囲の最小値
     * @param to
     *            範囲の最大値
     * @return 指定の範囲内の場合のみ<code>true</code>
     */
    public static boolean isRangeAll(long[] a, long from, long to) {
        for (int i = 0; i < a.length; i++) {
            if (!Eval.isRange(a[i], from, to)) {
                return false;
            }
        }
        return true;
    }

    /**
     * 指定された数値が指定の範囲内か評価します。
     * 
     * @param a
     *            評価する数値
     * @param from
     *            範囲の最小値
     * @param to
     *            範囲の最大値
     * @return 指定の範囲内の場合のみ<code>true</code>
     */
    public static boolean isRangeAll(float[] a, float from, float to) {
        for (int i = 0; i < a.length; i++) {
            if (!Eval.isRange(a[i], from, to)) {
                return false;
            }
        }
        return true;
    }

    /**
     * 指定された数値が指定の範囲内か評価します。
     * 
     * @param a
     *            評価する数値
     * @param from
     *            範囲の最小値
     * @param to
     *            範囲の最大値
     * @return 指定の範囲内の場合のみ<code>true</code>
     */
    public static boolean isRangeAll(double[] a, double from, double to) {
        for (int i = 0; i < a.length; i++) {
            if (!Eval.isRange(a[i], from, to)) {
                return false;
            }
        }
        return true;
    }

}
