/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.lang;

import java.io.PrintStream;
import java.io.PrintWriter;

/**
 * 指定された識別子が誤りである事を通知します。
 */
public class IllegalIdentifierException extends RuntimeException {

    /** <code>serialVersionUID</code>。 */
    private static final long serialVersionUID = -2421893269581565528L;

    /**
     * デフォルトコンストラクタ。
     */
    public IllegalIdentifierException() {
        super();
    }

    /**
     * エラーメッセージを設定して初期化します。
     * 
     * @param message
     *            エラーメッセージ
     */
    public IllegalIdentifierException(String message) {
        super(message);
    }

    /**
     * 起因例外を設定して初期化します。
     * 
     * @param cause
     *            起因例外
     */
    public IllegalIdentifierException(Throwable cause) {
        super(cause);
    }

    /**
     * エラーメッセージと起因例外を設定して初期化します。
     * 
     * @param message
     *            エラーメッセージ
     * @param cause
     *            起因例外
     */
    public IllegalIdentifierException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * スタックトレースを出力します。 <br>
     * 起因例外のスタックトレースも出力します。
     */
    public void printStackTrace() {
        super.printStackTrace();
        Throwable cause = getCause();
        if (cause != null) {
            cause.printStackTrace();
        }
    }

    /**
     * PrintWriterにスタックトレースを出力します。 <br>
     * 起因例外のスタックトレースも出力します。
     * 
     * @param s
     *            java.io.PrintWriter
     */
    public void printStackTrace(PrintWriter s) {
        super.printStackTrace(s);
        Throwable cause = getCause();
        if (cause != null) {
            cause.printStackTrace(s);
        }
    }

    /**
     * PrintStreamにスタックトレースを出力します。 <br>
     * 起因例外のスタックトレースも出力します。
     * 
     * @param s
     *            java.io.PrintStream
     */
    public void printStackTrace(PrintStream s) {
        super.printStackTrace(s);
        Throwable cause = getCause();
        if (cause != null) {
            cause.printStackTrace(s);
        }
    }

}
