/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.util;

import java.io.IOException;
import java.io.InputStream;
import java.util.Map;

/**
 * <code>CELResourceBundle</code>用の階層化リソースバンドルを生成する機能を提供します。
 */
class CELResourceBundleCreater implements XResourceBundleCreater {

    private final XResourceBundleBaseCalculator bundleBaseCalculator;

    /* ロケールの束縛基準で初期化します。 */
    CELResourceBundleCreater() {
        this(new LocaleResourceBundleBaseCalculator());
    }

    /* 指定の束縛基準を格納して初期化します。 */
    CELResourceBundleCreater(XResourceBundleBaseCalculator calculator) {
        this.bundleBaseCalculator = calculator;
    }

    /* CELResourceBundle の新規インスタンスを生成して返却します。 */
    public XResourceBundle createBundle(ClassLoader loader, XResourceBundle parent, Object bundleBase, String baseName,
            String bundleName) {

        InputStream stream = XResourceBundleHelper.getPropertiesBundleInputStream(loader, bundleName);
        if (stream != null) {
            try {

                CELProperties props = new CELProperties();
                props.load(stream);
                Map resources = props.toMap();
                return new CELResourceBundle(parent, bundleBase, resources);

            } catch (IOException e) {
                // no op
            } finally {
                try {
                    stream.close();
                } catch (Exception e) {
                    // no op
                }
            }
        }
        return null;
    }

    /* CELResourceBundle のクラスローダを返却します。 */
    public ClassLoader getDefaultClassLoader() {
        return CELResourceBundle.class.getClassLoader();
    }

    /* リソースを階層状に束ねる束縛基準を返却します。 */
    public XResourceBundleBaseCalculator getBundleBaseCalculator() {
        return this.bundleBaseCalculator;
    }
}