/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.util;

/**
 * 拡張可能な階層化リソースバンドルのリソースを束ねるための束縛基準を定義する機能を提供します。<br>
 * 階層化リソースバンドルは、このインターフェースの実装に基づき階層化されます。<br>
 * <br>
 * <b>このオブジェクトはスレッドセーフである必要が有ります。<br>
 * 基本的に可変のフィールドは保有せずに各メソッド内部で処理が完結するべきです。 <b>
 */
public interface XResourceBundleBaseCalculator {

    /**
     * バンドルのデフォルトの束縛基準を返却します。
     * 
     * @return デフォルトの束縛基準
     */
    Object getDefaultBundleBase();

    /**
     * バンドル名から束縛基準の識別子を算出して返却します。
     * 
     * @param bundleBase
     *            束縛基準
     * @return バンドル名から束縛基準の識別子
     */
    String candidateBundleId(Object bundleBase);

    /**
     * バンドル名から束縛基準を算出して返却します。
     * 
     * @param baseName
     *            拡張リソースバンドルの基底名
     * @param bundleName
     *            基底名にロケール情報を付加したバンドル名
     * @return バンドル名から算出される束縛基準
     */
    Object calculateBundleBase(String baseName, String bundleName);

    /**
     * バンドルの検索候補となるバンドル名を算出し上位の階層順で返却します。
     * 
     * @param baseName
     *            基底名
     * @param bundleBase
     *            束縛基準
     * @return 候補となるバンドル名
     */
    String[] candidateHierarchyBundleNames(String baseName, Object bundleBase);
}
