/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.util;

/**
 * 拡張可能な階層化リソースバンドルを生成する機能を提供します。<br>
 * <br>
 * <b>このオブジェクトはスレッドセーフである必要が有ります。<br>
 * 基本的に可変のフィールドは保有せずに各メソッド内部で処理が完結するべきです。 <b>
 */
public interface XResourceBundleCreater {

    /**
     * リソースを階層状に束ねる束縛基準を返却します。
     * 
     * @return リソースを階層状に束ねる束縛基準
     */
    XResourceBundleBaseCalculator getBundleBaseCalculator();

    /**
     * バンドルの実装の新規インスタンスを生成して返却します。
     * 
     * @param loader
     *            クラスリーダ
     * @param parent
     *            親バンドル、親がない場合<code>null</code>
     * @param bundleBase
     *            リソースの束縛基準
     * @param baseName
     *            規定名
     * @param bundleName
     *            リソースの固有名
     * @return バンドルの実装の新規インスタンス
     */
    XResourceBundle createBundle(ClassLoader loader, XResourceBundle parent, Object bundleBase, String baseName,
            String bundleName);

    /**
     * リソースの生成に使用するデフォルトのクラスローダを返却します。
     * 
     * @return デフォルトのクラスローダ
     */
    ClassLoader getDefaultClassLoader();
}
