/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.util.cel;

import java.util.Iterator;

/**
 * 合成式言語 <code>CEL(Composite CELExpression Language)</code> の実行式から参照されるコンテキストを提供します。
 */
public interface CELContext {

    /**
     * 全ての属性名の反復子を返却します。
     * 
     * @return 属性名の反復子
     */
    Iterator nameIterator();

    /**
     * 引数の名前を持つ属性値を返却します。 <br>
     * 指定された属性が存在しない場合は<code>null</code>が返されます。
     * 
     * @param name
     *            属性名
     * @return 属性値
     */
    Object getValue(String name);

    /**
     * 引数の名前で属性を格納します。 <br>
     * 既存の属性が存在する場合、既存の属性値を返却します。 <br>
     * 既存の属性が存在しない場合は<code>null</code>が返されます。
     * 
     * @param name
     *            属性名
     * @param value
     *            属性値
     * @return 既存の属性値、存在しない場合は null
     */
    Object setValue(String name, Object value);

    /**
     * 引数の名前が存在する場合<code>true</code>を返却します。
     * 
     * @param name
     *            属性名
     * @return 引数の名前が存在する場合<code>true</code>
     */
    boolean containsName(String name);

}
