/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.util.cel;

/**
 * 合成式言語 <code>CEL(Composite CELExpression Language)</code> の「式」を提供します。<br>
 * リテラル文字で論理分割される式文の個々のノードの実体です。
 */
public interface CELExpression {

    /**
     * 文字列式内のこの式の区画を分割するリテラル文字を返却します。
     * 
     * @return リテラル文字
     */
    CELLiteral getLiteral();

    /**
     * 式を実行して値を返却します。
     * 
     * @param binder
     *            処理基のバインダー
     * @param expression
     *            式
     * @param beginIndex
     *            開始インデックス
     * @param context
     *            引数値の一覧
     * @return 式の結果
     */
    CELReturnValue execute(CELBinder binder, String expression, int beginIndex, CELContext context);

}