/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.util.cel;

import shohaku.core.lang.Boxing;
import shohaku.core.util.codec.UnicodeEscapesCoder;

/**
 * 文字を生成する式を提供します。
 */
public class CharacterExpression implements CELExpression {

    /* この式のリテラル文字を定義します。 */
    private static final CELLiteral literal = new CELLiteral('\'', '\'');

    /**
     * 文字リテラル ''', ''' を返却します。
     * 
     * @return リテラル文字
     */
    public CELLiteral getLiteral() {
        return literal;
    }

    /**
     * 式を実行して値を返却します。
     * 
     * @param binder
     *            処理基のバインダー
     * @param expression
     *            式
     * @param beginIndex
     *            開始インデックス
     * @param context
     *            引数値の一覧
     * @return 式の結果
     */
    public CELReturnValue execute(CELBinder binder, String expression, int beginIndex, CELContext context) {
        int nextIndex = CELHelper.findNextIndex(expression, beginIndex, literal.end);
        if (-1 == nextIndex) {
            throw new CELFormatException("format err :" + expression);
        }
        String exp = expression.substring(beginIndex + 1, nextIndex - 1);
        String schar = exp.replaceFirst("\\'", "'");
        if (schar.length() > 1) {
            schar = UnicodeEscapesCoder.decode(schar);
        }
        if (schar.length() != 1) {
            throw new CELFormatException("format err :" + exp);
        }
        return new CELReturnValue(Boxing.box(schar.charAt(0)), nextIndex);
    }

}
